/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: ICommonMethodMetadata.java 3771 2008-07-29 13:49:21Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api;

import org.ow2.util.ee.metadata.common.api.interfaces.ISharedMetadata;
import org.ow2.util.scan.api.metadata.IMethodMetadata;

/**
 * The common interface for method metadata.
 * @param <C> the common interface for class metadata
 * @param <M> the common interface for method metadata
 * @param <F> the common interface for field metadata
 * @author Gael Lalire
 */
public interface ICommonMethodMetadata<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ISharedMetadata, IMethodMetadata<C, M, F> {

    /**
     * @return true if method has &#64;{@link javax.annotation.PostConstruct}.
     */
    boolean isPostConstruct();

    /**
     * Sets true if method has &#64;{@link javax.annotation.PostConstruct}.
     * @param postConstruct true/false.
     */
    void setPostConstruct(final boolean postConstruct);

    /**
     * @return true if method has &#64;{@link javax.annotation.PreDestroy}.
     */

    boolean isPreDestroy();

    /**
     * Sets true if method has &#64;{@link javax.annotation.PreDestroy}.
     * @param preDestroy true/false.
     */
    void setPreDestroy(final boolean preDestroy);

}
