/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IJaxwsWebServiceRef.java 3979 2008-09-28 11:02:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.struct;

/**
 * Manage WebServiceRef metadata.
 * @author Guillaume Sauthier
 */
public interface IJaxwsWebServiceRef {

    /**
     * @return A product specific name that this resource should be mapped to.
     */
    String getMappedName();

    /**
     * A product specific name that this resource should be mapped to.
     * @param mappedName product specific name
     */
    void setMappedName(String mappedName);

    /**
     * @return The JNDI name of the resource.
     */
    String getName();

    /**
     * The JNDI name of the resource.
     * @param name JNDI name
     */
    void setName(String name);

    /**
     * @return The Java type of the resource.
     */
    String getType();

    /**
     * The Java type of the resource.
     * @param type Java type
     */
    void setType(String type);

    /**
     * The service class, always a type extending javax.xml.ws.Service. This element
     * must be specified whenever the type of the reference is a service endpoint interface.
     * @return The service class, always a type extending javax.xml.ws.Service
     */
    String getValue();

    /**
     * This element must be specified whenever the type of the reference is a
     * service endpoint interface.
     * @param value The service class, always a type extending javax.xml.ws.Service
     */
    void setValue(String value);

    /**
     * @return A URL pointing to the WSDL document for the web service.
     */
    String getWsdlLocation();

    /**
     * A URL pointing to the WSDL document for the web service.
     * If not specified, the WSDL location specified by annotations on the resource
     * type is used instead.
     * @param wsdlLocation Absolute URL or relative URL (to the module)
     */
    void setWsdlLocation(String wsdlLocation);
}
