/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IJwsHandlerChain.java 3979 2008-09-28 11:02:27Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.api.struct;

/**
 * Manage @HandlerChain (from JSR-181) annotation + holds XML serialized
 * form of handler-chains if coming from XML.
 * At most one of the 'file' or 'XMLSerializedForm' attribute is set.
 * @author Guillaume Sauthier
 */
public interface IJwsHandlerChain {

    /**
     * @return the absolute URL or relative path to the handler chain file or null.
     */
    String getFile();

    /**
     * Set the location of the handler chain file.
     * @param file location of the handler chain file.
     */
    void setFile(String file);

    /**
     * Return the XML serialized form of a &lt;handler-chains&gt; element.
     * This method may return null.
     * @return the XML serialized form of a &lt;handler-chains&gt; element.
     */
    String getXMLSerializedForm();

    /**
     * Stores the XML serialized form of a &lt;handler-chains&gt; element.
     * @param serializedForm the given serialized form
     */
    void setXMLSerializedForm(String serializedForm);
}
